@@ -1,6 +1,7 @@
 #include <algorithm>
 #include <boost/asio.hpp>
-#include <boost/filesystem.hpp>
+
+#include <filesystem>
 #include <sstream>
 #include <stdexcept>
 #include <utility>
@@ -9,13 +10,12 @@
 #include "SocketCommunication.hpp"
 #include "SocketRequest.hpp"
 #include "logging/LogMacros.hpp"
-#include "precice/types.hpp"
+#include "precice/impl/Types.hpp"
 #include "utils/assertion.hpp"
 #include "utils/networking.hpp"
 #include "utils/span_tools.hpp"
 
-namespace precice {
-namespace com {
+namespace precice::com {
 
 namespace asio = boost::asio;
 
@@ -27,7 +27,7 @@ SocketCommunication::SocketCommunication(unsigned short portNumber,
       _reuseAddress(reuseAddress),
       _networkName(std::move(networkName)),
       _addressDirectory(std::move(addressDirectory)),
-      _ioService(new IOService)
+      _ioContext(new IOContext)
 {
   if (_addressDirectory.empty()) {
     _addressDirectory = ".";
@@ -72,7 +72,7 @@ void SocketCommunication::acceptConnection(std::string const &acceptorName,
 
     using asio::ip::tcp;
 
-    tcp::acceptor acceptor(*_ioService);
+    tcp::acceptor acceptor(*_ioContext);
     tcp::endpoint endpoint(tcp::v4(), _portNumber);
 
     acceptor.open(endpoint.protocol());
@@ -91,9 +91,12 @@ void SocketCommunication::acceptConnection(std::string const &acceptorName,
     int requesterCommunicatorSize = -1;
 
     do {
-      auto socket = std::make_shared<Socket>(*_ioService);
+      auto socket = std::make_shared<Socket>(*_ioContext);
 
       acceptor.accept(*socket);
+      boost::asio::ip::tcp::no_delay option(true);
+      socket->set_option(option);
+
       PRECICE_DEBUG("Accepted connection at {}", address);
       _isConnected = true;
 
@@ -104,7 +107,7 @@ void SocketCommunication::acceptConnection(std::string const &acceptorName,
       PRECICE_ASSERT(_sockets.count(requesterRank) == 0,
                      "Rank {} has already been connected. Duplicate requests are not allowed.", requesterRank);
 
-      _sockets[requesterRank] = socket;
+      _sockets[requesterRank] = std::move(socket);
       // send and receive expect a rank from the acceptor perspective.
       // Thus we need to apply given rankOffset before passing it to send/receive.
       // This is essentially the inverse of adjustRank().
@@ -128,10 +131,9 @@ void SocketCommunication::acceptConnection(std::string const &acceptorName,
     PRECICE_ERROR("Accepting a socket connection at {} failed with the system error: {}", address, e.what());
   }
 
-  // NOTE:
-  // Keep IO service running so that it fires asynchronous handlers from another thread.
-  _work   = std::make_shared<asio::io_service::work>(*_ioService);
-  _thread = std::thread([this] { _ioService->run(); });
+  // NOTE: Keep IO context running so that it fires asynchronous handlers from another thread.
+  _workGuard = std::make_unique<WorkGuard>(boost::asio::make_work_guard(_ioContext->get_executor()));
+  _thread    = std::thread([this] { _ioContext->run(); });
 }
 
 void SocketCommunication::acceptConnectionAsServer(std::string const &acceptorName,
@@ -158,7 +160,7 @@ void SocketCommunication::acceptConnectionAsServer(std::string const &acceptorNa
 
     using asio::ip::tcp;
 
-    tcp::acceptor acceptor(*_ioService);
+    tcp::acceptor acceptor(*_ioContext);
     {
       tcp::endpoint endpoint(tcp::v4(), _portNumber);
 
@@ -177,14 +179,16 @@ void SocketCommunication::acceptConnectionAsServer(std::string const &acceptorNa
     PRECICE_DEBUG("Accepting connection at {}", address);
 
     for (int connection = 0; connection < requesterCommunicatorSize; ++connection) {
-      auto socket = std::make_shared<Socket>(*_ioService);
+      auto socket = std::make_shared<Socket>(*_ioContext);
       acceptor.accept(*socket);
+      boost::asio::ip::tcp::no_delay option(true);
+      socket->set_option(option);
       PRECICE_DEBUG("Accepted connection at {}", address);
       _isConnected = true;
 
       int requesterRank;
       asio::read(*socket, asio::buffer(&requesterRank, sizeof(int)));
-      _sockets[requesterRank] = socket;
+      _sockets[requesterRank] = std::move(socket);
     }
 
     acceptor.close();
@@ -192,9 +196,9 @@ void SocketCommunication::acceptConnectionAsServer(std::string const &acceptorNa
     PRECICE_ERROR("Accepting a socket connection at {} failed with the system error: {}", address, e.what());
   }
 
-  // NOTE: Keep IO service running so that it fires asynchronous handlers from another thread.
-  _work   = std::make_shared<asio::io_service::work>(*_ioService);
-  _thread = std::thread([this] { _ioService->run(); });
+  // NOTE: Keep IO context running so that it fires asynchronous handlers from another thread.
+  _workGuard = std::make_unique<WorkGuard>(boost::asio::make_work_guard(_ioContext->get_executor()));
+  _thread    = std::thread([this] { _ioContext->run(); });
 }
 
 void SocketCommunication::requestConnection(std::string const &acceptorName,
@@ -215,16 +219,16 @@ void SocketCommunication::requestConnection(std::string const &acceptorName,
   _portNumber                  = static_cast<unsigned short>(std::stoul(portNumber));
 
   try {
-    auto socket = std::make_shared<Socket>(*_ioService);
+    auto socket = std::make_shared<Socket>(*_ioContext);
 
     using asio::ip::tcp;
 
-    tcp::resolver::query query(tcp::v4(), ipAddress, portNumber, tcp::resolver::query::numeric_host);
-
     while (not isConnected()) {
-      tcp::resolver                resolver(*_ioService);
-      tcp::resolver::endpoint_type endpoint = *(resolver.resolve(query));
-      boost::system::error_code    error    = asio::error::host_not_found;
+      tcp::resolver resolver(*_ioContext);
+      auto          results = resolver.resolve(ipAddress, portNumber, boost::asio::ip::resolver_base::numeric_host);
+
+      auto                      endpoint = results.begin()->endpoint();
+      boost::system::error_code error    = asio::error::host_not_found;
       socket->connect(endpoint, error);
 
       _isConnected = not error;
@@ -232,10 +236,12 @@ void SocketCommunication::requestConnection(std::string const &acceptorName,
       if (not isConnected()) {
         // Wait a little, since after a couple of ten-thousand trials the system
         // seems to get confused and the requester connects wrongly to itself.
-        boost::asio::deadline_timer timer(*_ioService, boost::posix_time::milliseconds(1));
+        boost::asio::deadline_timer timer(*_ioContext, boost::posix_time::milliseconds(1));
         timer.wait();
       }
     }
+    boost::asio::ip::tcp::no_delay option(true);
+    socket->set_option(option);
 
     PRECICE_DEBUG("Requested connection to {}", address);
 
@@ -243,7 +249,7 @@ void SocketCommunication::requestConnection(std::string const &acceptorName,
 
     int acceptorRank = -1;
     asio::read(*socket, asio::buffer(&acceptorRank, sizeof(int)));
-    _sockets[0] = socket; // should be acceptorRank instead of 0, likewise all communication below
+    _sockets[0] = std::move(socket); // should be acceptorRank instead of 0, likewise all communication below
 
     send(requesterCommunicatorSize, 0);
 
@@ -251,14 +257,14 @@ void SocketCommunication::requestConnection(std::string const &acceptorName,
     PRECICE_ERROR("Requesting a socket connection at {} failed with the system error: {}", address, e.what());
   }
 
-  // NOTE: Keep IO service running so that it fires asynchronous handlers from another thread.
-  _work   = std::make_shared<asio::io_service::work>(*_ioService);
-  _thread = std::thread([this] { _ioService->run(); });
+  // NOTE: Keep IO context running so that it fires asynchronous handlers from another thread.
+  _workGuard = std::make_unique<WorkGuard>(boost::asio::make_work_guard(_ioContext->get_executor()));
+  _thread    = std::thread([this] { _ioContext->run(); });
 }
 
-void SocketCommunication::requestConnectionAsClient(std::string const &  acceptorName,
-                                                    std::string const &  requesterName,
-                                                    std::string const &  tag,
+void SocketCommunication::requestConnectionAsClient(std::string const   &acceptorName,
+                                                    std::string const   &requesterName,
+                                                    std::string const   &tag,
                                                     std::set<int> const &acceptorRanks,
                                                     int                  requesterRank)
 
@@ -276,41 +282,42 @@ void SocketCommunication::requestConnectionAsClient(std::string const &  accepto
     _portNumber                     = static_cast<unsigned short>(std::stoul(portNumber));
 
     try {
-      auto socket = std::make_shared<Socket>(*_ioService);
+      auto socket = std::make_shared<Socket>(*_ioContext);
 
       using asio::ip::tcp;
 
       PRECICE_DEBUG("Requesting connection to {}, port {}", ipAddress, portNumber);
 
-      tcp::resolver::query query(tcp::v4(), ipAddress, portNumber, tcp::resolver::query::numeric_host);
-
       while (not isConnected()) {
-        tcp::resolver             resolver(*_ioService);
-        tcp::resolver::iterator   endpoint_iterator = resolver.resolve(query);
-        boost::system::error_code error             = asio::error::host_not_found;
-        boost::asio::connect(*socket, endpoint_iterator, error);
+        tcp::resolver resolver(*_ioContext);
+        auto          endpoints = resolver.resolve(ipAddress, portNumber, boost::asio::ip::resolver_base::numeric_host);
+
+        boost::system::error_code error = asio::error::host_not_found;
+        boost::asio::connect(*socket, endpoints, error);
 
         _isConnected = not error;
 
         if (not isConnected()) {
           // Wait a little, since after a couple of ten-thousand trials the system
           // seems to get confused and the requester connects wrongly to itself.
-          boost::asio::deadline_timer timer(*_ioService, boost::posix_time::milliseconds(1));
+          boost::asio::deadline_timer timer(*_ioContext, boost::posix_time::milliseconds(1));
           timer.wait();
         }
       }
+      boost::asio::ip::tcp::no_delay option(true);
+      socket->set_option(option);
 
       PRECICE_DEBUG("Requested connection to {}, rank = {}", address, acceptorRank);
-      _sockets[acceptorRank] = socket;
+      _sockets[acceptorRank] = std::move(socket);
       send(requesterRank, acceptorRank); // send my rank
 
     } catch (std::exception &e) {
       PRECICE_ERROR("Requesting a socket connection at {} failed with the system error: {}", address, e.what());
     }
   }
-  // NOTE: Keep IO service running so that it fires asynchronous handlers from another thread.
-  _work   = std::make_shared<asio::io_service::work>(*_ioService);
-  _thread = std::thread([this] { _ioService->run(); });
+  // NOTE: Keep IO context running so that it fires asynchronous handlers from another thread.
+  _workGuard = std::make_unique<WorkGuard>(boost::asio::make_work_guard(_ioContext->get_executor()));
+  _thread    = std::thread([this] { _ioContext->run(); });
 }
 
 void SocketCommunication::closeConnection()
@@ -321,8 +328,8 @@ void SocketCommunication::closeConnection()
     return;
 
   if (_thread.joinable()) {
-    _work.reset();
-    _ioService->stop();
+    _workGuard.reset();
+    _ioContext->stop();
     _thread.join();
   }
 
@@ -331,10 +338,10 @@ void SocketCommunication::closeConnection()
 
     try {
       socket.second->shutdown(Socket::shutdown_send);
+      socket.second->close();
     } catch (std::exception &e) {
       PRECICE_WARN("Socket shutdown failed with system error: {}", e.what());
     }
-    socket.second->close();
   }
 
   _isConnected = false;
@@ -377,12 +384,12 @@ void SocketCommunication::send(precice::span<const int> itemsToSend, Rank rankRe
 void SocketCommunication::prepareEstablishment(std::string const &acceptorName,
                                                std::string const &requesterName)
 {
-  using namespace boost::filesystem;
+  using namespace std::filesystem;
   path dir = com::impl::localDirectory(acceptorName, requesterName, _addressDirectory);
   PRECICE_DEBUG("Creating connection exchange directory {}", dir.generic_string());
   try {
     create_directories(dir);
-  } catch (const boost::filesystem::filesystem_error &e) {
+  } catch (const std::filesystem::filesystem_error &e) {
     PRECICE_WARN("Creating directory for connection info failed with filesystem error: {}", e.what());
   }
 }
@@ -390,12 +397,12 @@ void SocketCommunication::prepareEstablishment(std::string const &acceptorName,
 void SocketCommunication::cleanupEstablishment(std::string const &acceptorName,
                                                std::string const &requesterName)
 {
-  using namespace boost::filesystem;
+  using namespace std::filesystem;
   path dir = com::impl::localDirectory(acceptorName, requesterName, _addressDirectory);
   PRECICE_DEBUG("Removing connection exchange directory {}", dir.generic_string());
   try {
     remove_all(dir);
-  } catch (const boost::filesystem::filesystem_error &e) {
+  } catch (const std::filesystem::filesystem_error &e) {
     PRECICE_WARN("Cleaning up connection info failed with filesystem error {}", e.what());
   }
 }
@@ -481,7 +488,7 @@ void SocketCommunication::send(int itemToSend, Rank rankReceiver)
 
   rankReceiver = adjustRank(rankReceiver);
 
-  PRECICE_ASSERT(rankReceiver >= 0, rankReceiver)
+  PRECICE_ASSERT(rankReceiver >= 0, rankReceiver);
   PRECICE_ASSERT(isConnected());
 
   try {
@@ -777,7 +784,7 @@ std::string SocketCommunication::getIpAddress()
   auto pos = std::find_if(interfaces.begin(), interfaces.end(),
                           [&](Interface const &interface) { return interface.name == _networkName; });
   if (pos == interfaces.end()) {
-    PRECICE_DEBUG("There  NOTHING");
+    PRECICE_DEBUG("There's NOTHING");
     std::ostringstream err;
     err << "Cannot find network interface \"" << _networkName << "\". Available interfaces are: ";
     for (const auto &interface : interfaces) {
@@ -795,5 +802,4 @@ std::string SocketCommunication::getIpAddress()
 #endif
 }
 
-} // namespace com
-} // namespace precice
+} // namespace precice::com
