@@ -2,8 +2,7 @@
 
 #include <memory>
 
-namespace precice {
-namespace mapping {
+namespace precice::mapping {
 
 class Mapping;
 class MappingConfiguration;
@@ -11,5 +10,4 @@ class MappingConfiguration;
 using PtrMapping              = std::shared_ptr<Mapping>;
 using PtrMappingConfiguration = std::shared_ptr<MappingConfiguration>;
 
-} // namespace mapping
-} // namespace precice
+} // namespace precice::mapping
