@@ -6,8 +6,9 @@
 #include <memory>
 #include <string>
 #include <vector>
-#include "com/CommunicateBoundingBox.hpp"
+
 #include "com/Communication.hpp"
+#include "com/Extra.hpp"
 #include "com/SharedPointer.hpp"
 #include "m2n/M2N.hpp"
 #include "mapping/Mapping.hpp"
@@ -25,12 +26,10 @@
 #include "testing/Testing.hpp"
 #include "utils/assertion.hpp"
 
-namespace precice {
-namespace mesh {
+namespace precice::mesh {
 class Edge;
 class Vertex;
-} // namespace mesh
-} // namespace precice
+} // namespace precice::mesh
 
 using namespace precice;
 using namespace partition;
@@ -39,14 +38,15 @@ using precice::testing::TestContext;
 BOOST_AUTO_TEST_SUITE(PartitionTests)
 BOOST_AUTO_TEST_SUITE(ProvidedPartitionTests)
 
+PRECICE_TEST_SETUP("NASTIN"_on(1_rank), "SOLIDZ"_on(3_ranks).setupIntraComm(), Require::Events)
 BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate2D)
 {
-  PRECICE_TEST("NASTIN"_on(1_rank), "SOLIDZ"_on(3_ranks).setupIntraComm(), Require::Events);
+  PRECICE_TEST();
   auto m2n = context.connectPrimaryRanks("NASTIN", "SOLIDZ");
 
   int dimensions = 2;
 
-  if (context.isNamed("NASTIN")) { //NASTIN
+  if (context.isNamed("NASTIN")) { // NASTIN
     mesh::PtrMesh pSolidzMesh(new mesh::Mesh("SolidzMesh", dimensions, testing::nextMeshID()));
 
     double safetyFactor = 0.1;
@@ -55,24 +55,24 @@ BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate2D)
     part.addM2N(m2n);
     part.communicate();
 
-    BOOST_TEST(pSolidzMesh->vertices().size() == 6);
+    BOOST_TEST(pSolidzMesh->nVertices() == 6);
     BOOST_TEST(pSolidzMesh->edges().size() == 4);
 
     for (int i = 0; i < 6; i++) {
-      BOOST_TEST(pSolidzMesh->vertices().at(i).getGlobalIndex() == i);
+      BOOST_TEST(pSolidzMesh->vertex(i).getGlobalIndex() == i);
     }
-  } else { //SOLIDZ
+  } else { // SOLIDZ
     mesh::PtrMesh pSolidzMesh(new mesh::Mesh("SolidzMesh", dimensions, testing::nextMeshID()));
 
-    if (context.isPrimary()) { //Primary
+    if (context.isPrimary()) { // Primary
       Eigen::VectorXd position(dimensions);
       position << 0.0, 0.0;
       mesh::Vertex &v1 = pSolidzMesh->createVertex(position);
       position << 0.0, 1.5;
       mesh::Vertex &v2 = pSolidzMesh->createVertex(position);
       pSolidzMesh->createEdge(v1, v2);
-    } else if (context.isRank(1)) { //SecondaryRank1
-    } else if (context.isRank(2)) { //Secondary rank 2
+    } else if (context.isRank(1)) { // SecondaryRank1
+    } else if (context.isRank(2)) { // Secondary rank 2
       Eigen::VectorXd position(dimensions);
       position << 0.0, 3.5;
       mesh::Vertex &v3 = pSolidzMesh->createVertex(position);
@@ -98,7 +98,7 @@ BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate2D)
       BOOST_TEST(pSolidzMesh->getVertexOffsets().at(0) == 2);
       BOOST_TEST(pSolidzMesh->getVertexOffsets().at(1) == 2);
       BOOST_TEST(pSolidzMesh->getVertexOffsets().at(2) == 6);
-    } else if (context.isRank(1)) { //SecondaryRank1
+    } else if (context.isRank(1)) { // SecondaryRank1
       BOOST_TEST(pSolidzMesh->getVertexOffsets().at(0) == 2);
       BOOST_TEST(pSolidzMesh->getVertexOffsets().at(1) == 2);
       BOOST_TEST(pSolidzMesh->getVertexOffsets().at(2) == 6);
@@ -110,14 +110,15 @@ BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate2D)
   }
 }
 
+PRECICE_TEST_SETUP("NASTIN"_on(1_rank), "SOLIDZ"_on(3_ranks).setupIntraComm(), Require::Events)
 BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate3D)
 {
-  PRECICE_TEST("NASTIN"_on(1_rank), "SOLIDZ"_on(3_ranks).setupIntraComm(), Require::Events);
+  PRECICE_TEST();
   auto m2n = context.connectPrimaryRanks("NASTIN", "SOLIDZ");
 
   int dimensions = 3;
 
-  if (context.isNamed("NASTIN")) { //NASTIN
+  if (context.isNamed("NASTIN")) { // NASTIN
     mesh::PtrMesh pSolidzMesh(new mesh::Mesh("SolidzMesh", dimensions, testing::nextMeshID()));
 
     double safetyFactor = 0.1;
@@ -126,25 +127,25 @@ BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate3D)
     part.addM2N(m2n);
     part.communicate();
 
-    BOOST_TEST(pSolidzMesh->vertices().size() == 6);
+    BOOST_TEST(pSolidzMesh->nVertices() == 6);
     BOOST_TEST(pSolidzMesh->edges().size() == 6);
     BOOST_TEST(pSolidzMesh->triangles().size() == 2);
 
     for (int i = 0; i < 6; i++) {
-      BOOST_TEST(pSolidzMesh->vertices().at(i).getGlobalIndex() == i);
+      BOOST_TEST(pSolidzMesh->vertex(i).getGlobalIndex() == i);
     }
-  } else { //SOLIDZ
+  } else { // SOLIDZ
     mesh::PtrMesh pSolidzMesh(new mesh::Mesh("SolidzMesh", dimensions, testing::nextMeshID()));
 
-    if (context.isPrimary()) { //Primary
+    if (context.isPrimary()) { // Primary
       Eigen::VectorXd position(dimensions);
       position << 0.0, 0.0, 0.0;
       mesh::Vertex &v1 = pSolidzMesh->createVertex(position);
       position << 0.0, 1.5, 1.0;
       mesh::Vertex &v2 = pSolidzMesh->createVertex(position);
       pSolidzMesh->createEdge(v1, v2);
-    } else if (context.isRank(1)) { //SecondaryRank1
-    } else if (context.isRank(2)) { //Secondary rank 2
+    } else if (context.isRank(1)) { // SecondaryRank1
+    } else if (context.isRank(2)) { // Secondary rank 2
       Eigen::VectorXd position(dimensions);
       position << 0.0, 3.5, 0.1;
       mesh::Vertex &v3 = pSolidzMesh->createVertex(position);
@@ -154,11 +155,11 @@ BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate3D)
       mesh::Vertex &v5 = pSolidzMesh->createVertex(position);
       position << 0.0, 7.0, 0.4;
       mesh::Vertex &v6 = pSolidzMesh->createVertex(position);
-      mesh::Edge &  e1 = pSolidzMesh->createEdge(v3, v4);
-      mesh::Edge &  e2 = pSolidzMesh->createEdge(v4, v5);
-      mesh::Edge &  e3 = pSolidzMesh->createEdge(v5, v3);
-      mesh::Edge &  e4 = pSolidzMesh->createEdge(v3, v6);
-      mesh::Edge &  e5 = pSolidzMesh->createEdge(v6, v5);
+      mesh::Edge   &e1 = pSolidzMesh->createEdge(v3, v4);
+      mesh::Edge   &e2 = pSolidzMesh->createEdge(v4, v5);
+      mesh::Edge   &e3 = pSolidzMesh->createEdge(v5, v3);
+      mesh::Edge   &e4 = pSolidzMesh->createEdge(v3, v6);
+      mesh::Edge   &e5 = pSolidzMesh->createEdge(v6, v5);
 
       pSolidzMesh->createTriangle(e1, e2, e3);
       pSolidzMesh->createTriangle(e4, e5, e3);
@@ -197,12 +198,12 @@ BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate3D)
       BOOST_TEST(vertexDistribution.at(2).at(1) == 3);
       BOOST_TEST(vertexDistribution.at(2).at(2) == 4);
       BOOST_TEST(vertexDistribution.at(2).at(3) == 5);
-    } else if (context.isRank(1)) { //SecondaryRank1
+    } else if (context.isRank(1)) { // SecondaryRank1
       BOOST_REQUIRE(vertexOffsets.size() == 3);
       BOOST_TEST(vertexOffsets.at(0) == 2);
       BOOST_TEST(vertexOffsets.at(1) == 2);
       BOOST_TEST(vertexOffsets.at(2) == 6);
-    } else if (context.isRank(2)) { //Secondary rank 2
+    } else if (context.isRank(2)) { // Secondary rank 2
       BOOST_REQUIRE(vertexOffsets.size() == 3);
       BOOST_TEST(vertexOffsets.at(0) == 2);
       BOOST_TEST(vertexOffsets.at(1) == 2);
@@ -221,26 +222,27 @@ BOOST_AUTO_TEST_CASE(TestGatherAndCommunicate3D)
   }
 }
 
+PRECICE_TEST_SETUP("NASTIN"_on(4_ranks).setupIntraComm(), Require::Events)
 BOOST_AUTO_TEST_CASE(TestOnlyDistribution2D)
 {
-  PRECICE_TEST("NASTIN"_on(4_ranks).setupIntraComm(), Require::Events);
+  PRECICE_TEST();
   // Create mesh object
   std::string   meshName("MyMesh");
   int           dim = 2;
   mesh::PtrMesh pMesh(new mesh::Mesh(meshName, dim, testing::nextMeshID()));
 
-  if (context.isPrimary()) { //Primary
+  if (context.isPrimary()) { // Primary
     Eigen::VectorXd position(dim);
     position << 0.0, 0.0;
     pMesh->createVertex(position);
     position << 1.0, 0.0;
     pMesh->createVertex(position);
-  } else if (context.isRank(1)) { //SecondaryRank1
+  } else if (context.isRank(1)) { // SecondaryRank1
     Eigen::VectorXd position(dim);
     position << 2.0, 0.0;
     pMesh->createVertex(position);
-  } else if (context.isRank(2)) { //Secondary rank 2
-  } else if (context.isRank(3)) { //Secondary rank 3
+  } else if (context.isRank(2)) { // Secondary rank 2
+  } else if (context.isRank(3)) { // Secondary rank 3
     Eigen::VectorXd position(dim);
     position << 3.0, 0.0;
     pMesh->createVertex(position);
@@ -255,51 +257,52 @@ BOOST_AUTO_TEST_CASE(TestOnlyDistribution2D)
 
   BOOST_TEST_CONTEXT(*pMesh)
   {
-    if (context.isPrimary()) { //Primary
+    if (context.isPrimary()) { // Primary
       BOOST_TEST(pMesh->getGlobalNumberOfVertices() == 5);
       BOOST_TEST_REQUIRE(pMesh->getVertexOffsets().size() == 4);
       BOOST_TEST(pMesh->getVertexOffsets().at(0) == 2);
       BOOST_TEST(pMesh->getVertexOffsets().at(1) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(2) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(3) == 5);
-      BOOST_TEST(pMesh->vertices().at(0).getGlobalIndex() == 0);
-      BOOST_TEST(pMesh->vertices().at(1).getGlobalIndex() == 1);
-      BOOST_TEST(pMesh->vertices().at(0).isOwner() == true);
-      BOOST_TEST(pMesh->vertices().at(1).isOwner() == true);
-    } else if (context.isRank(1)) { //SecondaryRank1
+      BOOST_TEST(pMesh->vertex(0).getGlobalIndex() == 0);
+      BOOST_TEST(pMesh->vertex(1).getGlobalIndex() == 1);
+      BOOST_TEST(pMesh->vertex(0).isOwner() == true);
+      BOOST_TEST(pMesh->vertex(1).isOwner() == true);
+    } else if (context.isRank(1)) { // SecondaryRank1
       BOOST_TEST(pMesh->getGlobalNumberOfVertices() == 5);
       BOOST_TEST_REQUIRE(pMesh->getVertexOffsets().size() == 4);
       BOOST_TEST(pMesh->getVertexOffsets().at(0) == 2);
       BOOST_TEST(pMesh->getVertexOffsets().at(1) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(2) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(3) == 5);
-      BOOST_TEST(pMesh->vertices().at(0).getGlobalIndex() == 2);
-      BOOST_TEST(pMesh->vertices().at(0).isOwner() == true);
-    } else if (context.isRank(2)) { //Secondary rank 2
+      BOOST_TEST(pMesh->vertex(0).getGlobalIndex() == 2);
+      BOOST_TEST(pMesh->vertex(0).isOwner() == true);
+    } else if (context.isRank(2)) { // Secondary rank 2
       BOOST_TEST(pMesh->getGlobalNumberOfVertices() == 5);
       BOOST_TEST_REQUIRE(pMesh->getVertexOffsets().size() == 4);
       BOOST_TEST(pMesh->getVertexOffsets().at(0) == 2);
       BOOST_TEST(pMesh->getVertexOffsets().at(1) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(2) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(3) == 5);
-    } else if (context.isRank(3)) { //Secondary rank 3
+    } else if (context.isRank(3)) { // Secondary rank 3
       BOOST_TEST(pMesh->getGlobalNumberOfVertices() == 5);
       BOOST_TEST_REQUIRE(pMesh->getVertexOffsets().size() == 4);
       BOOST_TEST(pMesh->getVertexOffsets().at(0) == 2);
       BOOST_TEST(pMesh->getVertexOffsets().at(1) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(2) == 3);
       BOOST_TEST(pMesh->getVertexOffsets().at(3) == 5);
-      BOOST_TEST(pMesh->vertices().at(0).getGlobalIndex() == 3);
-      BOOST_TEST(pMesh->vertices().at(1).getGlobalIndex() == 4);
-      BOOST_TEST(pMesh->vertices().at(0).isOwner() == true);
-      BOOST_TEST(pMesh->vertices().at(1).isOwner() == true);
+      BOOST_TEST(pMesh->vertex(0).getGlobalIndex() == 3);
+      BOOST_TEST(pMesh->vertex(1).getGlobalIndex() == 4);
+      BOOST_TEST(pMesh->vertex(0).isOwner() == true);
+      BOOST_TEST(pMesh->vertex(1).isOwner() == true);
     }
   }
 }
 
+PRECICE_TEST_SETUP("SOLIDZ"_on(3_ranks).setupIntraComm(), "NASTIN"_on(1_rank), Require::Events)
 BOOST_AUTO_TEST_CASE(TestCompareBoundingBoxes2D)
 {
-  PRECICE_TEST("SOLIDZ"_on(3_ranks).setupIntraComm(), "NASTIN"_on(1_rank), Require::Events);
+  PRECICE_TEST();
   testing::ConnectionOptions options;
   options.useOnlyPrimaryCom = false;
   options.useTwoLevelInit   = true;
@@ -307,11 +310,11 @@ BOOST_AUTO_TEST_CASE(TestCompareBoundingBoxes2D)
 
   int dimensions = 2;
 
-  if (context.isNamed("SOLIDZ")) { //SOLIDZ
+  if (context.isNamed("SOLIDZ")) { // SOLIDZ
 
     mesh::PtrMesh pSolidzMesh(new mesh::Mesh("SolidzMesh", dimensions, testing::nextMeshID()));
 
-    if (context.isPrimary()) { //Primary
+    if (context.isPrimary()) { // Primary
       Eigen::VectorXd position(dimensions);
       position << -1.0, 0.0;
       mesh::Vertex &v0 = pSolidzMesh->createVertex(position);
@@ -323,14 +326,14 @@ BOOST_AUTO_TEST_CASE(TestCompareBoundingBoxes2D)
       pSolidzMesh->createEdge(v1, v2);
     }
 
-    else if (context.isRank(1)) { //SecondaryRank1
+    else if (context.isRank(1)) { // SecondaryRank1
       Eigen::VectorXd position(dimensions);
       position << 1.0, 3.5;
       mesh::Vertex &v3 = pSolidzMesh->createVertex(position);
       position << 0.0, 4.5;
       mesh::Vertex &v4 = pSolidzMesh->createVertex(position);
       pSolidzMesh->createEdge(v3, v4);
-    } else if (context.isRank(2)) { //Secondary rank 2
+    } else if (context.isRank(2)) { // Secondary rank 2
       Eigen::VectorXd position(dimensions);
       position << 2.5, 5.5;
       mesh::Vertex &v5 = pSolidzMesh->createVertex(position);
@@ -344,21 +347,21 @@ BOOST_AUTO_TEST_CASE(TestCompareBoundingBoxes2D)
     part.addM2N(m2n);
     part.compareBoundingBoxes();
 
-    if (context.isPrimary()) { //Primary
+    if (context.isPrimary()) { // Primary
       BOOST_TEST(pSolidzMesh->getConnectedRanks().size() == 2);
       BOOST_TEST(pSolidzMesh->getConnectedRanks().at(0) == 1);
       BOOST_TEST(pSolidzMesh->getConnectedRanks().at(1) == 2);
-    } else if (context.isRank(1)) { //SecondaryRank1
+    } else if (context.isRank(1)) { // SecondaryRank1
       BOOST_TEST(pSolidzMesh->getConnectedRanks().size() == 2);
       BOOST_TEST(pSolidzMesh->getConnectedRanks().at(0) == 0);
       BOOST_TEST(pSolidzMesh->getConnectedRanks().at(1) == 2);
-    } else if (context.isRank(2)) { //Secondary rank 2
+    } else if (context.isRank(2)) { // Secondary rank 2
       BOOST_TEST(pSolidzMesh->getConnectedRanks().size() == 2);
       BOOST_TEST(pSolidzMesh->getConnectedRanks().at(0) == 0);
       BOOST_TEST(pSolidzMesh->getConnectedRanks().at(1) == 1);
     }
 
-  } else { //NASTIN
+  } else { // NASTIN
     BOOST_TEST(context.isNamed("NASTIN"));
 
     mesh::Mesh::BoundingBoxMap receivedGlobalBB;
@@ -378,11 +381,11 @@ BOOST_AUTO_TEST_CASE(TestCompareBoundingBoxes2D)
     }
 
     // we receive global bounding box from other participant!
-    com::CommunicateBoundingBox(m2n->getPrimaryRankCommunication()).receiveBoundingBoxMap(receivedGlobalBB, 0);
+    com::receiveBoundingBoxMap(*m2n->getPrimaryRankCommunication(), 0, receivedGlobalBB);
     // check whether we have received the correct com size
     BOOST_TEST(receivedFeedbackSize == 3);
 
-    //check the validity of received global bounding box (globalBB)
+    // check the validity of received global bounding box (globalBB)
     BOOST_TEST(receivedGlobalBB.at(0) == compareBB.at(0));
     BOOST_TEST(receivedGlobalBB.at(1) == compareBB.at(1));
     BOOST_TEST(receivedGlobalBB.at(2) == compareBB.at(2));
@@ -399,13 +402,14 @@ BOOST_AUTO_TEST_CASE(TestCompareBoundingBoxes2D)
     connectionMap[2].push_back(0);
     connectionMap[2].push_back(1);
 
-    com::CommunicateBoundingBox(m2n->getPrimaryRankCommunication()).sendConnectionMap(connectionMap, 0);
+    com::sendConnectionMap(*m2n->getPrimaryRankCommunication(), 0, connectionMap);
   }
 }
 
+PRECICE_TEST_SETUP("SOLIDZ"_on(3_ranks).setupIntraComm(), "NASTIN"_on(1_rank), Require::Events)
 BOOST_AUTO_TEST_CASE(TestSendBoundingBoxes3D)
 {
-  PRECICE_TEST("SOLIDZ"_on(3_ranks).setupIntraComm(), "NASTIN"_on(1_rank), Require::Events);
+  PRECICE_TEST();
   testing::ConnectionOptions options;
   options.useOnlyPrimaryCom = false;
   options.useTwoLevelInit   = true;
@@ -413,11 +417,11 @@ BOOST_AUTO_TEST_CASE(TestSendBoundingBoxes3D)
 
   int dimensions = 3;
 
-  if (context.isNamed("SOLIDZ")) { //SOLIDZ
+  if (context.isNamed("SOLIDZ")) { // SOLIDZ
 
     mesh::PtrMesh pSolidzMesh(new mesh::Mesh("SolidzMesh", dimensions, testing::nextMeshID()));
 
-    if (context.isPrimary()) { //Primary
+    if (context.isPrimary()) { // Primary
       Eigen::VectorXd position(dimensions);
       position << -1.0, 0.0, -1.0;
       mesh::Vertex &v0 = pSolidzMesh->createVertex(position);
@@ -429,14 +433,14 @@ BOOST_AUTO_TEST_CASE(TestSendBoundingBoxes3D)
       pSolidzMesh->createEdge(v1, v2);
     }
 
-    else if (context.isRank(1)) { //SecondaryRank1
+    else if (context.isRank(1)) { // SecondaryRank1
       Eigen::VectorXd position(dimensions);
       position << 1.0, 3.5, 1.0;
       mesh::Vertex &v3 = pSolidzMesh->createVertex(position);
       position << 0.0, 4.5, 0.0;
       mesh::Vertex &v4 = pSolidzMesh->createVertex(position);
       pSolidzMesh->createEdge(v3, v4);
-    } else if (context.isRank(2)) { //Secondary rank 2
+    } else if (context.isRank(2)) { // Secondary rank 2
       Eigen::VectorXd position(dimensions);
       position << 2.5, 5.5, 2.5;
       mesh::Vertex &v5 = pSolidzMesh->createVertex(position);
@@ -450,7 +454,7 @@ BOOST_AUTO_TEST_CASE(TestSendBoundingBoxes3D)
     part.addM2N(m2n);
     part.compareBoundingBoxes();
 
-  } else { //NASTIN
+  } else { // NASTIN
     BOOST_TEST(context.isNamed("NASTIN"));
 
     mesh::Mesh::BoundingBoxMap receivedGlobalBB;
@@ -470,26 +474,27 @@ BOOST_AUTO_TEST_CASE(TestSendBoundingBoxes3D)
     }
 
     // we receive global bounding box from other participant!
-    com::CommunicateBoundingBox(m2n->getPrimaryRankCommunication()).receiveBoundingBoxMap(receivedGlobalBB, 0);
+    com::receiveBoundingBoxMap(*m2n->getPrimaryRankCommunication(), 0, receivedGlobalBB);
 
     // check whether we have received the correct com size
     BOOST_TEST(remoteParComSize == 3);
 
-    //check the validity of received global bounding box (globalBB)
+    // check the validity of received global bounding box (globalBB)
     BOOST_TEST(receivedGlobalBB.at(0) == compareBB.at(0));
     BOOST_TEST(receivedGlobalBB.at(1) == compareBB.at(1));
     BOOST_TEST(receivedGlobalBB.at(2) == compareBB.at(2));
 
-    //send empty dummy list of connected ranks as feedback
+    // send empty dummy list of connected ranks as feedback
     std::vector<int> connectedRanksList;
     m2n->getPrimaryRankCommunication()->sendRange(connectedRanksList, 0);
   }
 }
 
+PRECICE_TEST_SETUP("Solid"_on(2_ranks).setupIntraComm(), "Fluid"_on(2_ranks).setupIntraComm(), Require::Events)
 BOOST_AUTO_TEST_CASE(TestCommunicateLocalMeshPartitions)
 {
-  PRECICE_TEST("Solid"_on(2_ranks).setupIntraComm(), "Fluid"_on(2_ranks).setupIntraComm(), Require::Events);
-  //mesh creation
+  PRECICE_TEST();
+  // mesh creation
   int           dimensions   = 2;
   double        safetyFactor = 0.1;
   mesh::PtrMesh mesh(new mesh::Mesh("mesh", dimensions, testing::nextMeshID()));
@@ -516,7 +521,7 @@ BOOST_AUTO_TEST_CASE(TestCommunicateLocalMeshPartitions)
       mesh->createEdge(v3, v4);
       mesh->createEdge(v4, v1);
 
-      mesh->getConnectedRanks().push_back(0);
+      mesh->setConnectedRanks({0});
 
     } else {
       Eigen::VectorXd position(dimensions);
@@ -533,14 +538,14 @@ BOOST_AUTO_TEST_CASE(TestCommunicateLocalMeshPartitions)
       mesh->createEdge(v3, v4);
       mesh->createEdge(v4, v1);
 
-      mesh->getConnectedRanks().push_back(1);
+      mesh->setConnectedRanks({1});
     }
   } else {
     BOOST_TEST(context.isNamed("Fluid"));
     if (context.isPrimary()) {
-      mesh->getConnectedRanks().push_back(0);
+      mesh->setConnectedRanks({0});
     } else {
-      mesh->getConnectedRanks().push_back(1);
+      mesh->setConnectedRanks({1});
     }
   }
   mesh->computeBoundingBox();
@@ -559,34 +564,35 @@ BOOST_AUTO_TEST_CASE(TestCommunicateLocalMeshPartitions)
 
     part.communicate();
 
-    BOOST_TEST(mesh->vertices().size() == 4);
+    BOOST_TEST(mesh->nVertices() == 4);
 
     if (context.isPrimary()) {
-      BOOST_TEST(mesh->vertices().at(0).getCoords()(0) == 0.5);
-      BOOST_TEST(mesh->vertices().at(0).getCoords()(1) == 0.0);
-      BOOST_TEST(mesh->vertices().at(1).getCoords()(0) == 1.5);
-      BOOST_TEST(mesh->vertices().at(1).getCoords()(1) == 0.0);
-      BOOST_TEST(mesh->vertices().at(2).getCoords()(0) == 2.0);
-      BOOST_TEST(mesh->vertices().at(2).getCoords()(1) == 1.0);
-      BOOST_TEST(mesh->vertices().at(3).getCoords()(0) == 0.5);
-      BOOST_TEST(mesh->vertices().at(3).getCoords()(1) == 1.0);
+      BOOST_TEST(mesh->vertex(0).coord(0) == 0.5);
+      BOOST_TEST(mesh->vertex(0).coord(1) == 0.0);
+      BOOST_TEST(mesh->vertex(1).coord(0) == 1.5);
+      BOOST_TEST(mesh->vertex(1).coord(1) == 0.0);
+      BOOST_TEST(mesh->vertex(2).coord(0) == 2.0);
+      BOOST_TEST(mesh->vertex(2).coord(1) == 1.0);
+      BOOST_TEST(mesh->vertex(3).coord(0) == 0.5);
+      BOOST_TEST(mesh->vertex(3).coord(1) == 1.0);
     } else {
-      BOOST_TEST(mesh->vertices().at(0).getCoords()(0) == 2.5);
-      BOOST_TEST(mesh->vertices().at(0).getCoords()(1) == 0.0);
-      BOOST_TEST(mesh->vertices().at(1).getCoords()(0) == 3.5);
-      BOOST_TEST(mesh->vertices().at(1).getCoords()(1) == 0.0);
-      BOOST_TEST(mesh->vertices().at(2).getCoords()(0) == 3.5);
-      BOOST_TEST(mesh->vertices().at(2).getCoords()(1) == 1.0);
-      BOOST_TEST(mesh->vertices().at(3).getCoords()(0) == 2.0);
-      BOOST_TEST(mesh->vertices().at(3).getCoords()(1) == 1.0);
+      BOOST_TEST(mesh->vertex(0).coord(0) == 2.5);
+      BOOST_TEST(mesh->vertex(0).coord(1) == 0.0);
+      BOOST_TEST(mesh->vertex(1).coord(0) == 3.5);
+      BOOST_TEST(mesh->vertex(1).coord(1) == 0.0);
+      BOOST_TEST(mesh->vertex(2).coord(0) == 3.5);
+      BOOST_TEST(mesh->vertex(2).coord(1) == 1.0);
+      BOOST_TEST(mesh->vertex(3).coord(0) == 2.0);
+      BOOST_TEST(mesh->vertex(3).coord(1) == 1.0);
     }
   }
 }
 
+PRECICE_TEST_SETUP("Solid"_on(2_ranks).setupIntraComm(), "Fluid"_on(2_ranks).setupIntraComm(), Require::Events)
 BOOST_AUTO_TEST_CASE(TestTwoLevelRepartitioning2D)
 {
-  PRECICE_TEST("Solid"_on(2_ranks).setupIntraComm(), "Fluid"_on(2_ranks).setupIntraComm(), Require::Events);
-  //mesh creation
+  PRECICE_TEST();
+  // mesh creation
   int           dimensions   = 2;
   double        safetyFactor = 0;
   mesh::PtrMesh mesh(new mesh::Mesh("mesh", dimensions, testing::nextMeshID()));
@@ -721,11 +727,12 @@ BOOST_AUTO_TEST_CASE(TestTwoLevelRepartitioning2D)
   }
 }
 
+PRECICE_TEST_SETUP("Solid"_on(2_ranks).setupIntraComm(), "Fluid"_on(2_ranks).setupIntraComm(), Require::Events)
 BOOST_AUTO_TEST_CASE(TestTwoLevelRepartitioning3D)
 {
-  PRECICE_TEST("Solid"_on(2_ranks).setupIntraComm(), "Fluid"_on(2_ranks).setupIntraComm(), Require::Events);
+  PRECICE_TEST();
 
-  //mesh creation
+  // mesh creation
   int           dimensions   = 3;
   double        safetyFactor = 0.0;
   mesh::PtrMesh mesh(new mesh::Mesh("mesh", dimensions, testing::nextMeshID()));
